@@ -19,6 +19,7 @@ sub match {
         'has been temporarily rate limited due to ip reputation',
         'ip/domain reputation problems',
         'likely suspicious due to the very low reputation',
+        'none/bad reputation', # t-online.de
         'temporarily deferred due to unexpected volume or user complaints', # Yahoo Inc.
         "the sending mta's poor reputation",
     ];
@@ -37,8 +38,7 @@ sub true {
     my $argvs = shift // return undef;
 
     return 1 if $argvs->{'reason'} eq 'badreputation';
-    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
-    return 0;
+    return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
 
 1;
