@@ -20,6 +20,7 @@ sub match {
         'due to extended inactivity new mail is not currently being accepted for this mailbox',
         'has restricted sms e-mail',    # AT&T
         'is not accepting any mail',
+        "message filtered",
         'message rejected due to user rules',
         'not found recipient account',
         'refused due to recipient preferences', # Facebook
@@ -51,16 +52,16 @@ sub true {
 
     require Sisimai::Reason::UserUnknown;
     my $issuedcode = lc $argvs->{'diagnosticcode'};
-    my $thecommand = $argvs->{'smtpcommand'} || '';
+    my $thecommand = $argvs->{'command'} || '';
     if( $tempreason eq 'filtered' ) {
         # Delivery status code points "filtered".
         return 1 if Sisimai::Reason::UserUnknown->match($issuedcode);
         return 1 if __PACKAGE__->match($issuedcode);
 
     } else {
-        # The value of "reason" isn't "filtered" when the value of "smtpcommand" is an SMTP command
-        # to be sent before the SMTP DATA command because all the MTAs read the headers and the
-        # entire message body after the DATA command.
+        # The value of "reason" isn't "filtered" when the value of "command" is an SMTP command to
+        # be sent before the SMTP DATA command because all the MTAs read the headers and the entire
+        # message body after the DATA command.
         return 0 if $thecommand eq 'CONN' || $thecommand eq 'EHLO' || $thecommand eq 'HELO'
                  || $thecommand eq 'MAIL' || $thecommand eq 'RCPT';
         return 1 if __PACKAGE__->match($issuedcode);
